@@ -8,10 +8,7 @@
 
 // KF
 #include <KColorScheme>
-#include <kconfigwidgets_version.h>
-#if KCONFIGWIDGETS_VERSION >= QT_VERSION_CHECK(5, 93, 0)
-#include <KStatefulBrush> // was moved to own header in 5.93.0
-#endif
+#include <KStatefulBrush>
 // Qt
 #include <QGraphicsScene>
 #include <QGraphicsTextItem>
@@ -96,18 +93,9 @@ private:
     const KGamePopupItemPrivate &operator=(const KGamePopupItemPrivate &);
 
 public:
-    KGamePopupItemPrivate()
-        : m_position(KGamePopupItem::BottomLeft)
-        , m_timeout(2000)
-        , m_opacity(1.0)
-        , m_animOpacity(-1)
-        , m_hoveredByMouse(false)
-        , m_hideOnClick(true)
-        , m_textChildItem(nullptr)
-        , m_sharpness(KGamePopupItem::Square)
-        , m_linkHovered(false)
-    {
-    }
+    KGamePopupItemPrivate() = default;
+
+public:
     /**
      * Timeline for animations
      */
@@ -131,19 +119,19 @@ public:
     /**
      * Position where item will appear
      */
-    KGamePopupItem::Position m_position;
+    KGamePopupItem::Position m_position = KGamePopupItem::BottomLeft;
     /**
      * Timeout to stay visible on screen
      */
-    int m_timeout;
+    int m_timeout = 2000;
     /**
      * Item opacity
      */
-    qreal m_opacity;
+    qreal m_opacity = 1.0;
     /**
      * Opacity used while animating appearing in center
      */
-    qreal m_animOpacity;
+    qreal m_animOpacity = -1;
     /**
      * Pixmap to display at the left of the text
      */
@@ -151,15 +139,15 @@ public:
     /**
      * Set to true when mouse hovers the message
      */
-    bool m_hoveredByMouse;
+    bool m_hoveredByMouse = false;
     /**
      * Set to true if this popup item hides on mouse click.
      */
-    bool m_hideOnClick;
+    bool m_hideOnClick = true;
     /**
      * Child of KGamePopupItem used to display text
      */
-    TextItemWithOpacity *m_textChildItem;
+    TextItemWithOpacity *m_textChildItem = nullptr;
     /**
      * Part of the scene that is actually visible in QGraphicsView
      * This is needed for item to work correctly when scene is larger than
@@ -173,7 +161,7 @@ public:
     /**
      * popup angles sharpness
      */
-    KGamePopupItem::Sharpness m_sharpness;
+    KGamePopupItem::Sharpness m_sharpness = KGamePopupItem::Square;
     /**
      * painter path to draw a frame
      */
@@ -181,13 +169,15 @@ public:
     /**
      * Indicates if some link is hovered in text item
      */
-    bool m_linkHovered;
+    bool m_linkHovered = false;
 };
 
 KGamePopupItem::KGamePopupItem(QGraphicsItem *parent)
     : QGraphicsItem(parent)
-    , d(new KGamePopupItemPrivate)
+    , d_ptr(new KGamePopupItemPrivate)
 {
+    Q_D(KGamePopupItem);
+
     hide();
     d->m_textChildItem = new TextItemWithOpacity(this);
     d->m_textChildItem->setTextInteractionFlags(Qt::LinksAccessibleByMouse);
@@ -225,6 +215,8 @@ KGamePopupItem::~KGamePopupItem() = default;
 
 void KGamePopupItem::paint(QPainter *p, const QStyleOptionGraphicsItem *option, QWidget *widget)
 {
+    Q_D(KGamePopupItem);
+
     Q_UNUSED(option);
 
     p->save();
@@ -247,6 +239,8 @@ void KGamePopupItem::paint(QPainter *p, const QStyleOptionGraphicsItem *option,
 
 void KGamePopupItem::showMessage(const QString &text, Position pos, ReplaceMode mode)
 {
+    Q_D(KGamePopupItem);
+
     if (d->m_timeLine.state() == QTimeLine::Running || d->m_timer.isActive()) {
         if (mode == ReplacePrevious) {
             forceHide(InstantHide);
@@ -328,6 +322,8 @@ void KGamePopupItem::showMessage(const QString &text, Position pos, ReplaceMode
 
 void KGamePopupItem::setupTimeline()
 {
+    Q_D(KGamePopupItem);
+
     d->m_timeLine.setDirection(QTimeLine::Forward);
     d->m_timeLine.setDuration(300);
     if (d->m_position == TopLeft || d->m_position == TopRight) {
@@ -347,6 +343,8 @@ void KGamePopupItem::setupTimeline()
 
 void KGamePopupItem::animationFrame(int frame)
 {
+    Q_D(KGamePopupItem);
+
     if (d->m_position == TopLeft || d->m_position == BottomLeft) {
         setPos(d->m_visibleSceneRect.left() + d->m_mapped_SHOW_OFFSET, frame);
     } else if (d->m_position == TopRight || d->m_position == BottomRight) {
@@ -360,6 +358,8 @@ void KGamePopupItem::animationFrame(int frame)
 
 void KGamePopupItem::playHideAnimation()
 {
+    Q_D(KGamePopupItem);
+
     if (d->m_hoveredByMouse) {
         return;
     }
@@ -370,32 +370,44 @@ void KGamePopupItem::playHideAnimation()
 
 void KGamePopupItem::setMessageTimeout(int msec)
 {
+    Q_D(KGamePopupItem);
+
     d->m_timeout = msec;
 }
 
 void KGamePopupItem::setHideOnMouseClick(bool hide)
 {
+    Q_D(KGamePopupItem);
+
     d->m_hideOnClick = hide;
 }
 
 bool KGamePopupItem::hidesOnMouseClick() const
 {
+    Q_D(const KGamePopupItem);
+
     return d->m_hideOnClick;
 }
 
 void KGamePopupItem::setMessageOpacity(qreal opacity)
 {
+    Q_D(KGamePopupItem);
+
     d->m_opacity = opacity;
     d->m_textChildItem->setOpacity(opacity);
 }
 
 QRectF KGamePopupItem::boundingRect() const
 {
+    Q_D(const KGamePopupItem);
+
     return d->m_boundRect;
 }
 
 void KGamePopupItem::hideMe()
 {
+    Q_D(KGamePopupItem);
+
     d->m_animOpacity = -1;
     // and restore child's opacity too
     d->m_textChildItem->setOpacity(d->m_opacity);
@@ -409,11 +421,15 @@ void KGamePopupItem::hideMe()
 
 void KGamePopupItem::hoverEnterEvent(QGraphicsSceneHoverEvent *)
 {
+    Q_D(KGamePopupItem);
+
     d->m_hoveredByMouse = true;
 }
 
 void KGamePopupItem::hoverLeaveEvent(QGraphicsSceneHoverEvent *)
 {
+    Q_D(KGamePopupItem);
+
     d->m_hoveredByMouse = false;
 
     if (d->m_timeout != 0 && !d->m_timer.isActive() && d->m_timeLine.state() != QTimeLine::Running) {
@@ -423,6 +439,8 @@ void KGamePopupItem::hoverLeaveEvent(QGraphicsSceneHoverEvent *)
 
 void KGamePopupItem::setMessageIcon(const QPixmap &pix)
 {
+    Q_D(KGamePopupItem);
+
     d->m_iconPix = pix;
     d->m_textChildItem->setPos(MARGIN + pix.width() / pix.devicePixelRatio() + SOME_SPACE, MARGIN);
     // bounding rect is updated in showMessage()
@@ -430,11 +448,15 @@ void KGamePopupItem::setMessageIcon(const QPixmap &pix)
 
 int KGamePopupItem::messageTimeout() const
 {
+    Q_D(const KGamePopupItem);
+
     return d->m_timeout;
 }
 
 void KGamePopupItem::forceHide(HideType howToHide)
 {
+    Q_D(KGamePopupItem);
+
     if (!isVisible()) {
         return;
     }
@@ -455,22 +477,30 @@ void KGamePopupItem::forceHide(HideType howToHide)
 
 qreal KGamePopupItem::messageOpacity() const
 {
+    Q_D(const KGamePopupItem);
+
     return d->m_opacity;
 }
 
 void KGamePopupItem::setBackgroundBrush(const QBrush &brush)
 {
+    Q_D(KGamePopupItem);
+
     d->m_brush = KStatefulBrush(brush);
 }
 
 void KGamePopupItem::setTextColor(const QColor &color)
 {
+    Q_D(KGamePopupItem);
+
     KStatefulBrush brush(color, d->m_brush.brush(QPalette::Active));
     d->m_textChildItem->setTextColor(brush);
 }
 
 void KGamePopupItem::onLinkHovered(const QString &link)
 {
+    Q_D(KGamePopupItem);
+
     if (link.isEmpty()) {
         d->m_textChildItem->setCursor(Qt::ArrowCursor);
     } else {
@@ -483,11 +513,15 @@ void KGamePopupItem::onLinkHovered(const QString &link)
 
 void KGamePopupItem::setSharpness(Sharpness sharpness)
 {
+    Q_D(KGamePopupItem);
+
     d->m_sharpness = sharpness;
 }
 
 KGamePopupItem::Sharpness KGamePopupItem::sharpness() const
 {
+    Q_D(const KGamePopupItem);
+
     return d->m_sharpness;
 }
 
@@ -499,6 +533,8 @@ void KGamePopupItem::mousePressEvent(QGraphicsSceneMouseEvent *)
 
 void KGamePopupItem::mouseReleaseEvent(QGraphicsSceneMouseEvent *)
 {
+    Q_D(KGamePopupItem);
+
     // NOTE: text child item is QGraphicsTextItem which "eats" mouse events
     // because of interaction with links. Because of that TextItemWithOpacity has
     // special signal to indicate mouse click which we catch in a onTextItemClicked()
@@ -510,6 +546,8 @@ void KGamePopupItem::mouseReleaseEvent(QGraphicsSceneMouseEvent *)
 
 void KGamePopupItem::onTextItemClicked()
 {
+    Q_D(KGamePopupItem);
+
     // if link is hovered we don't hide as click should go to the link
     if (d->m_hideOnClick && !d->m_linkHovered) {
         forceHide();
